@@ -5,12 +5,9 @@ In this package we provide some additional tools for the usage of
 [cppyy](https://cppyy.readthedocs.io/en/latest/) in the Lyncs API.
 """
 
-__version__ = "0.1.5"
+__version__ = "0.2.0"
 
-from cppyy import nullptr, cppdef, gbl, include
+from cppyy import nullptr, cppdef, gbl, include, c_include, set_debug
 from .lib import *
-from . import ll
-
-# including and aliasing
-include(__path__[0] + "/utils.h")
-make_shared = gbl.lyncs_cppyy_make_shared
+from .numpy import *
+from .ll import *
